@@ -145,24 +145,34 @@ glade_column_list_copy (GList *list)
 	
 	for (l = list; l; l = g_list_next (l))
 	{
-		GladeColumnType *new_data = g_new0(GladeColumnType, 1);
 		GladeColumnType *data = l->data;
-		
-		new_data->type_name = g_strdup (data->type_name);
-		new_data->column_name = g_strdup (data->column_name);
-		
+		GladeColumnType *new_data = 
+			glade_column_type_new (data->type_name, data->column_name);
+
 		retval = g_list_prepend (retval, new_data);
 	}
 	
 	return g_list_reverse (retval);
 }
 
+GladeColumnType *
+glade_column_type_new (const gchar *type_name,
+		       const gchar *column_name)
+{
+	GladeColumnType *column = g_slice_new0 (GladeColumnType);
+
+	column->type_name   = g_strdup (type_name);
+	column->column_name = g_strdup (column_name);
+
+	return column;
+}
+
 void
 glade_column_type_free (GladeColumnType *column)
 {
 	g_free (column->type_name);
 	g_free (column->column_name);
-	g_free (column);
+	g_slice_free (GladeColumnType, column);
 }
 
 void
@@ -286,8 +296,7 @@ eprop_column_adjust_rows (GladeEditorProperty *eprop, GList *columns)
 
 		column = list->data;
 
-		if ((data_type = g_type_from_name (column->type_name)) == G_TYPE_INVALID)
-			data_type = G_TYPE_POINTER;
+		data_type = g_type_from_name (column->type_name);
 		
 		if ((idx = glade_model_data_column_index (data_tree, column->column_name)) < 0)
 		{
@@ -324,9 +333,7 @@ eprop_column_append (GladeEditorProperty *eprop,
 	if (columns)
 		columns = glade_column_list_copy (columns);
 
-	data = g_new0 (GladeColumnType, 1);
-	data->column_name = g_strdup (column_name);
-	data->type_name   = g_strdup (type_name);
+	data = glade_column_type_new (type_name, column_name);
 
 	columns = g_list_append (columns, data);
 
